pub type NumericSolutionResult<T: Float + Div + Sub + PartialOrd> = Result<T, T>;Expand description
A NumericSolutionResult is returned from the various nrfind functions.
An Ok value signifies a result that is within the given precision while an
Err result signifies a result that is not known to be sufficiently precise.
Aliased Type
pub enum NumericSolutionResult<T: Float + Div + Sub + PartialOrd> {
Ok(T),
Err(T),
}